==> mongodb-src-r3.1.3.zip: mongodb-src-r3.1.3/src/mongo/util/string_map.h <==
// string_map.h

/*    Copyright 2012 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#pragma once

#include "mongo/base/string_data.h"
#include "mongo/util/unordered_fast_key_table.h"

namespace mongo {

    typedef StringData::Hasher StringMapDefaultHash;

    struct StringMapDefaultEqual {
        bool operator()( StringData a, StringData b ) const {
            return a == b;
        }
    };

    struct StringMapDefaultConvertor {
        StringData operator()( const std::string& s ) const {
            return StringData( s );
        }
    };

    struct StringMapDefaultConvertorOther {
        std::string operator()( StringData s ) const {
            return s.toString();
        }
    };

    template< typename V >
    class StringMap : public UnorderedFastKeyTable< StringData, // K_L
                                                    std::string, // K_S
                                                    V,           // V
                                                    StringMapDefaultHash,
                                                    StringMapDefaultEqual,
                                                    StringMapDefaultConvertor,
                                                    StringMapDefaultConvertorOther > {
    };
}

==> mongodb-src-r3.1.8.zip: mongodb-src-r3.1.8/src/mongo/util/string_map.h <==
// string_map.h

/*    Copyright 2012 10gen Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects
 *    for all of the code used other than as permitted herein. If you modify
 *    file(s) with this exception, you may extend this exception to your
 *    version of the file(s), but you are not obligated to do so. If you do not
 *    wish to do so, delete this exception statement from your version. If you
 *    delete this exception statement from all source files in the program,
 *    then also delete it in the license file.
 */

#pragma once

#include "mongo/base/string_data.h"
#include "mongo/util/unordered_fast_key_table.h"

namespace mongo {

typedef StringData::Hasher StringMapDefaultHash;

struct StringMapDefaultEqual {
    bool operator()(StringData a, StringData b) const {
        return a == b;
    }
};

struct StringMapDefaultConvertor {
    StringData operator()(const std::string& s) const {
        return StringData(s);
    }
};

struct StringMapDefaultConvertorOther {
    std::string operator()(StringData s) const {
        return s.toString();
    }
};

template <typename V>
using StringMap = UnorderedFastKeyTable<StringData,   // K_L
                                        std::string,  // K_S
                                        V,
                                        StringMapDefaultHash,
                                        StringMapDefaultEqual,
                                        StringMapDefaultConvertor,
                                        StringMapDefaultConvertorOther>;
}  // namespace mongo
